#ifndef __TERRAIN_H_
#define __TERRAIN_H_

#include <stdio.h>

typedef struct
{
	int w, h;	// pixel dimensions
	float xs, ys;	// scales
	float *terrain;	// altitude data
} terrain_t;

#define PI	3.141592654
#define TWOPI	6.283185308

// in terrain.c
terrain_t *trn_new(int w, int h, float scale);
void trn_free(terrain_t *t);
void trn_raise(terrain_t *t, float h);
void trn_addcone(terrain_t *t, float x, float y, float r, float h);
void trn_addgaussian(terrain_t *t, float x, float y, float dev, float h);
void trn_tilt(terrain_t *t, float ax, float ay, float rx, float ry, float h);
void trn_fault(terrain_t *t, float ax, float ay, float rx, float ry, float h);
void trn_normalise(terrain_t *t, int h);
void trn_drawline(terrain_t *t, float x0, float y0, float h0, float x1, float y1, float h1);
void trn_cutoff(terrain_t *t);

void trn_minmax(terrain_t *t, float *min, float *max);

unsigned char *trn_bytearray(terrain_t *t, int *w, int *h, float *min, float *max);
void trn_writepgm(terrain_t *t, FILE *fp);
void trn_writecarray(terrain_t *t, FILE *fp, char *name);

// in fft.c
int trn_convolve(terrain_t *source, terrain_t *conv);
int trn_gaussiannoise(terrain_t *t, float mag, float dev);

// in ridges.c
void trn_ridges(terrain_t *t, terrain_t *profile, int n, float dr, float h, float dh);
void trn_addroughness(terrain_t *map, float mag, float k, float alpha);


#endif	// __TERRAIN_H_
